# Judy

A Python wrapper for Judy arrays, which provide fast and space-efficient integer
mappings and integer sets, along with ranged ordered iterations.

Additional information:
* [Jydy C Library](http://judy.sourceforge.net/)
* [Python source code](https://github.com/arnimarj/py-judy/)
* [Build instructions](./BUILD.md)
